pub fn build_frame_iter(file_path: &PathBuf, mode: &str) -> Result<FrameIter>Expand description
Build a frame iterator from a file path and mode (“ben” or “xben”)
Frame iteration is useful for subsampling since you do not need to decode every frame into an assignment vector. Since the BEN standard includes information about the number of bytes used to encode each frame, reading through the file and extracting particular frames is incredibly fast.
Arguments
file_path- A PathBuf pointing to the BEN or XBEN file.mode- A string slice indicating the file type: “ben” or “xben”.
Returns
An io::Result containing a boxed iterator over frames and their repetition counts.