pub fn decode_ben_to_jsonl<R: Read, W: Write>(
reader: R,
writer: W,
) -> Result<()>Expand description
This function takes a reader containing a file encoded in the BEN format and decodes it into a JSONL file.
The output JSONL file will have the formatting
{"assignment": [...], "sample": #}Errors
This function will return an error if the input reader contains invalid ben data or if the the decode method encounters while trying to extract a single assignment vector, that error is then propagated.