decode_xben_to_jsonl

Function decode_xben_to_jsonl 

pub fn decode_xben_to_jsonl<R: BufRead, W: Write>(
    reader: R,
    writer: W,
) -> Result<()>
This function takes a reader containing a file encoded in the XBEN format and decodes it into a JSONL file.

The output JSONL file will have the formatting

{"assignment": [...], "sample": #}

Errors

This function will return an error if the input reader contains invalid xben data or if the the decode method encounters while trying to extract a single assignment vector, that error is then propagated.