encode_ben_to_xben

Function encode_ben_to_xben 

pub fn encode_ben_to_xben<R: BufRead, W: Write>(
    reader: R,
    writer: W,
    n_threads: Option<u32>,
    compression_level: Option<u32>,
) -> Result<()>
This function takes a BEN file and encodes it into an XBEN file using bit-to-byte decompression followed by LZMA2 compression.

Arguments

  • reader - A buffered reader for the input file
  • writer - A writer for the output file
  • n_threads - The number of threads to use for compression (optional)
  • compression_level - The compression level to use (0-9, optional)

Returns

A Result type that contains the result of the operation