Function ben::utils::rle_to_vec

source ·
pub fn rle_to_vec(rle_vec: Vec<(u16, u16)>) -> Vec<u16>
Convert a run-length encoded (RLE) vector to a vector of assignments.

Arguments

  • rle_vec - A vector of tuples where the first element is the value and the second element is the length of the run.

Returns

A vector of assignments.