Module documentation.
This module provides functionality for extracting single assignment vectors from a BEN file.
Structs
- Error type for the extraction of assignments.
Enums
- Types of errors that can occur during the extraction of assignments.
Functions
- Extracts a single assignment from a binary-encoded data stream.