Function ben::encode::relabel::relabel_ben_lines
source · pub fn relabel_ben_lines<R: Read, W: Write>(reader: R, writer: W) -> Result<()>Expand description
Relabels each of the assignment vectors in a BEN file so that the values are in ascending order.
Arguments
reader- A reader that implements theReadtrait containing the BEN file to be relabeled.writer- A writer that implements theWritetrait and which will contain the relabeled BEN file.
Errors
Returns an error if the file format is invalid or if there is an issue reading or writing the file.