Module ben::encode::translate

source ·
This module contains the main functions that are used for translating between the ben32 and BEN formats. The ben32 format is a simple run-length encoding of an assignment vector done at the byte level and for which every 32 bits of data encodes a one (assignment, count) pair. The BEN format is a bit-packed version of the ben32 format along with some extra headers.

Functions

  • This function takes a reader that contains a several ben32 encoded assignment vectors and encodes them into ben encoded assignment vectors and writes them to the designated writer.
  • This function takes a reader that contains a several ben encoded assignment vectors and encodes them into ben32 encoded assignment vectors and writes them to the designated writer.